cmd

package
v2.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: MIT Imports: 31 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:           "go-arch",
	Short:         "A CLI tool to scaffold Go projects with clean architecture",
	Long:          `go-arch is a CLI library for Go that empowers developers to create projects with hexagonal or minimalist architecture.`,
	SilenceUsage:  true,
	SilenceErrors: true,
}
var Version = "dev"

Version is set by main after GoReleaser injects main.version.

Functions

func Execute

func Execute()

Types

This section is empty.

Jump to